*********************************;
* PROC UCM ON AIRLINE TIME SERIES;
*********************************;

title 'Using UCM to predict the Airline time series';
proc UCM data=Ax2018.Airline;
	id date interval=month;
	model logair;
	level plot=smooth;
	slope plot=smooth;
	season length=12 type=trig plot=smooth;
	irregular;
	estimate back=12 plot=(panel wn);
	outlier;
	forecast back=12 lead=12 plot=decomp outfor = air_ucmfcst;
run;

* LET US TRANSFROM THE FORECAST TO THE ORGINAL METRIC;
data air_fcst;
	set air_ucmfcst;
	air = exp(logair);
	fcst = exp(forecast);
	fcst_lower = exp(lcl);
	fcst_upper = exp(ucl);
	fcst_err = air - fcst;
	fcst_err_sqr = fcst_err**2;
	fcst_err_abs = abs(fcst_err);
	fcst_err_abs_perc = 100 * fcst_err_abs / air;
run;

* GRAPHS WITH RESPECT TO THE ORIGINAL VARIABLE;
proc sgplot data=air_fcst;
	title 'Airline and forecasts';
	band x=date lower=fcst_lower upper=fcst_upper;
	series x=date y=fcst;
	scatter x=date y=air;
	refline '15dec1959'd / axis = x;
run;

* LET US COMPUTE LOSS FUNCTIONS FOR THE OUT-OF-SAMPLE FORECAST ERROR;
proc means data = air_fcst(where = (date>'31dec1959'd)) mean min max;
	var fcst_err: ;
run;


*********************************;
* PROC SSM ON AIRLINE TIME SERIES;
*********************************;

title 'Using SSM to predict the Airline time series';
proc ssm data = Ax2018.Airline plot=all;
	id date interval = month;
	ynomiss = logair;   *makes the output file contain the full-length series logair;
	trend level(ll) checkbreak; *defines the local linear trend and ask for possible level shifts;
	state seas(1) type=season(length=12); *defines the state needed for the seasonal cmp;
	component seasonal = seas[1]; *defines the seasonal component from the state seas;
	irregular wn; *defines the irregular component has a white noise named wn;
	model logair0 = level seasonal wn; *defines the observation equation;
	output out=out_air pdv; *ask to produce the output file and include all variables created in ssm;
run;

* GRAPHS WITH RESPECT TO THE LOG-TRANSFORMED VARIABLE
* Plotting the smoothed trend with the original time series;
proc sgplot data=out_air;
	title 'Log-Airline and level';
	band x=date lower=Smoothed_Lower_level upper=Smoothed_Upper_level;
	series x=date y=Smoothed_level;
	series x=date y=forecast_logair0;
	scatter x=date y=ynomiss;
run;

* Plotting out-of-sample prediction with real observations;
proc sgplot data=out_air(where=(date>'31dec1959'd));
	title 'Out of sample predictions';
	band x=date lower=Lower_logair0 upper=Upper_logair0;
	series x=date y=forecast_logair0;
	scatter x=date y=ynomiss;
run;

* GRAPHS WITH RESPECT TO THE ORIGINAL VARIABLE;
data airline_fcst;
	set out_air;
	air = exp(ynomiss);
	fcst = exp(forecast_logair0);
	fcst_lower = exp(lower_logair0);
	fcst_upper = exp(upper_logair0);
	* let us generate the forecast errors and some transforms thereof;
	fcst_err = air - fcst;
	fcst_err_sqr = fcst_err**2;
	fcst_err_abs = abs(fcst_err);
	fcst_err_abs_perc = 100 * fcst_err_abs / air;
run;

* Plotting out-of-sample prediction with real observations;
proc sgplot data=airline_fcst(where=(date>'31dec1959'd));
	title 'Out of sample predictions';
	band x=date lower=fcst_lower upper=fcst_upper;
	series x=date y=fcst;
	scatter x=date y=air;
run;

proc means data = airline_fcst(where=(date>'31dec1959'd))
           mean max min;
	var fcst_err: ;
run;
