* FOUR TIME SERIES USED TO EXTRACT THE US BUSINESS CYCLE;

proc sgplot data=Ax2018.CBI;
	title 'Conference Board Index Series (growth rates)';
	series x=date y=emp;
	series x=date y=inc / lineattrs=(color = red);
	series x=date y=ipi / lineattrs=(color = green);
	series x=date y=sal / lineattrs=(color = brown);
run;

title 'Common cycle';
proc ssm data=Ax2018.CBI;
	id date interval=month;
	trend lev1(ps(2)) variance=0;
	trend lev2(ps(2)) variance=0;
	trend lev3(ps(2)) variance=0;
	trend lev4(ps(2)) variance=0;
	parms damp / lower=0.8 upper=0.99;
	parms per / lower=24 upper=96;
	parms c2 c3 c4 / lower=0;
	state cy(1) type=cycle(rho=damp period=per) cov(G);
	component cycle1 = cy[1];
	component cycle2 = (c2)*cy[1];
	component cycle3 = (c3)*cy[1];
	component cycle4 = (c4)*cy[1];
*	state mwn(4) type=wn cov(G); * this would generate correlated wn
*	component wn1 = mwn[1];
*	component wn2 = mwn[2];
*	component wn3 = mwn[3];
*	component wn4 = mwn[4];
	irregular wn1;
	irregular wn2;
	irregular wn3;
	irregular wn4;
	model emp = lev1 cycle1 wn1;
	model inc = lev2 cycle2 wn2;
	model ipi = lev3 cycle3 wn3;
	model sal = lev4 cycle4 wn4;
	output out=out_CBI pdv;
run;
proc sgplot data=OUT_CBI;
	title 'Rescaled common cycle';
	series x=date y=Smoothed_cycle1;
	*series x=date y=Smoothed_cycle2 / lineattrs=(color = red);
	*series x=date y=Smoothed_cycle3 / lineattrs=(color = green);
	*series x=date y=Smoothed_cycle4 / lineattrs=(color = brown);
run;

* LET'S TRY TO GET A SMOOTHER CYCLE BY USING ORDER-2 CYCLES
title 'Order 2 common cycle';
proc ssm data=Ax2018.CBI;
	id date interval=month;
	trend lev1(ps(2)) variance=0;
	trend lev2(ps(2)) variance=0;
	trend lev3(ps(2)) variance=0;
	trend lev4(ps(2)) variance=0;
	parms rho / lower=0.7 upper=0.99;
	parms lambda / upper=0.14 lower=0.02;
	parms c2 c3 c4 / lower=0;
	parms cyclevar / lower=0.00000001;
	* Making the transition matrix of higher order cycle;
	array cT{4,4};
	cl = rho*cos(lambda);
	sl = rho*sin(lambda);
	cT[1,1] = cl;
	cT[1,2] = sl;
	cT[2,1] = -sl;
	cT[2,2] = cl;
	cT[3,3] = cl;
	cT[3,4] = sl;
	cT[4,3] = -sl;
	cT[4,4] = cl;
	cT[1,3] = 1;
	cT[2,4] = 1;
	* Making the covariance matrix diagonal of highher order cycle;
	array cQ{4};
	cQ[1] = 0;
	cQ[2] = 0;
	cQ[3] = cyclevar;
	cQ[4] = cyclevar;
	state cy(4) T(G)=(cT) COV(D)=(cQ) a1(4) print=T print=cov; 
	component cycle1 = cy[1];
	component cycle2 = (c2)*cy[1];
	component cycle3 = (c3)*cy[1];
	component cycle4 = (c4)*cy[1];
	irregular wn1;
	irregular wn2;
	irregular wn3;
	irregular wn4;
	model emp = lev1 cycle1 wn1;
	model inc = lev2 cycle2 wn2;
	model ipi = lev3 cycle3 wn3;
	model sal = lev4 cycle4 wn4;
	output out=out_CBI2 pdv;
run;
proc sgplot data=OUT_CBI2;
	title 'Rescaled common cycle';
	series x=date y=Smoothed_cycle1;
	*series x=date y=Smoothed_cycle2 / lineattrs=(color = red);
	*series x=date y=Smoothed_cycle3 / lineattrs=(color = green);
	*series x=date y=Smoothed_cycle4 / lineattrs=(color = brown);
run;
