/* PLOT OF TIME SERIES FOR TWO YEARS */
proc sgplot data=Ax2018.elettroload;
	where date >= '1jan2013'd;
	series x=date y=h13;
run;

/* SAME PLOT, DIFFERENT WAY */
proc timeseries data = Ax2018.elettroload plot=series;
	where date >= '1jan2013'd;
	id date interval = day;
	var h13;
run;

/* UCM FOR LOAD AT 13TH HOUR */
proc ucm data=Ax2018.elettroload;
	id date interval=day;
	model h13=Aug15 BridgeDay Dec24 Dec25 Dec26 EasterSat EasterSun EasterMon 
		EasterTue EndYear Holidays HolySat HolySun Jan1 Jan6;
	irregular;
	level plot=smooth;
	season type=dummy length=7;
	season type=trig length=365 keeph=1 to 16 variance=0 plot=smooth;
	estimate back=60 plot=(panel);
	forecast back=60 lead=60 plot=(forecasts trend decomp) print=none;
run;

/* RELATION LOAD VS. TEMPERATURE */
proc sgplot data=Ax2018.Elettroload;
	loess x=Tmean y=h13 / smooth=0.4;
run;

/* UCM FOR LOAD AT 13TH HOUR USING BASIS SPLINES FOR TEMPRATURE */
proc ucm data=Ax2018.elettroload;
	id date interval=day;
	model h13=Aug15 BridgeDay Dec24 Dec25 Dec26 EasterSat EasterSun EasterMon 
		EasterTue EndYear Holidays HolySat HolySun Jan1 Jan6;
	splinereg Tmean knots = 18 degree = 2 plot=smooth variance = 0 noest;
	irregular;
	level plot=smooth;
	season type=dummy length=7;
	season type=trig length=365 keeph=1 to 16 variance=0 plot=smooth;
	estimate back=60 plot=panel;
	forecast back=60 lead=60 plot=forecasts;
run;

/* UCM FOR LOAD AT 13TH HOUR USING BASIS SPLINES FOR TEMPRATURE
   AND PERIODIC SPLINES FOR YEARLY SEASONALITY*/
proc ucm data=Ax2018.elettroload;
	id date interval=day;
	model h13=Aug15 BridgeDay Dec24 Dec25 Dec26 EasterSat EasterSun EasterMon 
		EasterTue EndYear Holidays HolySat HolySun Jan1 Jan6;
	splinereg Tmean knots = 18 degree = 2 plot=smooth variance = 0 noest;
	irregular;
	level plot=smooth;
	season type=dummy length=7;
	splineseason length=365 knots = ; 
	estimate back=60 plot=panel;
	forecast back=60 lead=60 plot=forecasts;
run;
