/*******************************************
 * TWO TIME SERIES:                        *
 * INDPRO = US INDUSTRIAL PRODUCTION INDEX *
 * GDP    = US REAL GDP                    *
 * ALL SERIES ARE SEASONALLY ADJUSTED      *
 *******************************************/

proc sgplot data=Ax2018.GDP_IPI_USA;
	title 'US Industrial Production Index (SA)';
	series x=date y=INDPRO;
run;

data GDP_IPI_USA;
	set Ax2018.GDP_IPI_USA;
	logindpro = log(indpro);
	loggdp = log(gdp);
run;

title 'PROC UCM: SMOTH TREND + CYCLE + NOISE';
proc ucm data=GDP_IPI_USA;
	id date interval=month;
	model logindpro;
	level variance=0 noest plot=smooth checkbreak;
	slope plot = smooth;
	cycle plot = smooth;
	irregular;
	estimate back = 12 plot=(panel);
	forecast back = 12 lead = 12 plot=forecasts;
run;




title 'PROC SSM: SMOTH TREND + CYCLE + NOISE';
proc ssm data=GDP_IPI_USA plot=residual(normal);
	id date interval=month;
	parms rho / lower=0.01 upper=0.99;
	parms per / lower=24 upper=96;
	trend level1(ps(2)) variance=0.0000001;
	state cy(1) type=cycle(rho=rho period=per) cov(G);
	component cycle1 = cy[1];
	irregular noise1;
	model logindpro = level1 cycle1 noise1;
	output out=out_gdp_ipi_usa pdv;
run;

proc sgplot data=out_gdp_ipi_usa;
	series x=date y=Smoothed_level1;
	series x=date y=logindpro / lineattrs=(color = red);
run;

proc sgplot data=out_gdp_ipi_usa;
	series x=date y=Smoothed_cycle1;
run;
