*************************************************************************;
* THIS TIME SERIES REPRESENT THE NUMBER OF INJURIES ON ITALIAN ROADS    *;
* IN JULY 2003 THE DRIVING LICENCE POINT SYSTEM WAS INTRODUCED IN ITALY *;
*************************************************************************;

title 'Monthly number of injured for car accident';
proc sgplot data=Ax2018.injured;
	series x=date y=injured;
run;

title 'PROC UCM: let us model Injuries and look for level shift';
proc ucm data=Ax2018.Injured;
	id date interval=month;
	model injured;
	irregular;
	level plot=smooth checkbreak;
	slope plot=smooth;
	season length=12 type=trigonometric plot=smooth;
	estimate plot=panel;
	outlier;
run;

* WE CAN MODEL THE LEVEL SHIFT IN JUL 2003 WITH A STEP VARIABLE;
title 'Point system and car accidents: Assessing the permanent effect on injuries';
data injured_step;
	set Ax2018.Injured;
	step = (date >= '1jul2003'd);
run;

proc ucm data=injured_step;
	id date interval=month;
	model injured=step;
	irregular;
	level plot=smooth checkbreak;
	season length=12 type=trig plot=smooth;
	estimate plot=panel;
	outlier;
run;

/* THERE SEEMS TO BE A DOWNWARD JUMP ON JUL2003, BUT MAYBE
   THERE IS A TRANSITORY EFFECT OF THIS NEW LAW AND A PERMANENT EFFECT
   AT THE MOMENT TRANSITORY EFFECTS CANNOT BE MODELLED WITH UCM,
   BUT SINCE NOV2018 IN THE NEW VERSION OF SAS/ETS THE PROC UCM
   WILL BE ABLE TO MODEL TRANSFER FUNCTION, WHICH ALLOWS THIS KIND OF EFFECT */

* NOW WE CAN USE SSM;
title 'Model with interventions';
proc ssm data=Ax2018.Injured plots=all optimizer(maxiter=100);
	id date interval=month;
	step    = (date >= '1jul2003'd);
	impulse = (date = '1jul2003'd);
	trend trend(ps(2)) checkbreak;
	state seas(1) type=season(length=12);
	component seasonal = seas[1];
	irregular noise;
	* building the transfer function;
	parms delta / lower=0 upper=0.95;
	state trans(1) T(G)=(delta) W(G)=(impulse);
	component transitory = trans[1];
	model Injured=trend seasonal noise step transitory;
	output out=out_injured pdv;
	eval permanent = step;
	eval toteffect = step + transitory;
	eval level_effect = trend + step + transitory;
run;

title 'Checking if residuals are white noise';
proc arima data=out_injured;
	identify var=RESIDUAL_Injured;
run;
proc sgplot data=out_injured;
	title 'Transitory + Permanent Effect';
	band x=date lower=Smoothed_Lower_toteffect upper=Smoothed_Upper_toteffect;
	series x=date y=Smoothed_toteffect;
run;
proc sgplot data=out_injured;
	title 'Level including effects';
	band x=date lower=Smoothed_Lower_level_effect upper=Smoothed_Upper_level_effect;
	series x=date y=Smoothed_level_effect;
	series x=date y=Injured;
run;
