***************;
* Nile series *;
***************;

* LET'S TAKE A LOOK;
proc sgplot data=Ax2018.Nile;
	series x=Date y=Nile;
run;

* LET US ESTIMATE AN UCM WITH;
* RANDOM WALK + NOISE AND CHECK FOR LEVEL SHIFTS;
title 'Nile data with UCM';
proc ucm data=Ax2018.Nile;
	id date interval=year;
	model Nile;
	irregular;
	level plot=smooth checkbreak; * CHECK LEVEL SHIFT;
	estimate plot=panel;
	outlier;
run;

* A LEVEL SHIFT IS DETECTED IN YEAR 1899;
* LET'S BUILD A STEP DUMMY VARIABLE TO MODELI IT;
title 'Nile data with break usign UCM';
data Nile_step;
	set Ax2018.Nile;
	step = (date > '31dec1898'd);
run;

* LET US ESTIMATE AN UCM WITH;
* RANDOM WALK + NOISE + STEP AND CHECK FOR LEVEL SHIFTS;
proc ucm data=Nile_step;
	id date interval=year;
	model Nile = step;
	irregular;
	level plot=smooth checkbreak; * CHECK LEVEL SHIFT;
	estimate plot=panel;
	outlier;
run;


* USING PROC SSM;
title 'Nile data with SSM: no break';
proc ssm data = Ax2018.Nile plots=all;
	id date interval=year;
	trend level(rw) checkbreak;
	irregular wn;
	model Nile = level wn;
run;

* WE NOTICE THE SAME LEVEL SHIFT: WE CAN MANAGE IT
* INSIDE THE PROC SSM;
title 'Nile data with SSM: with level shift';
proc ssm data = Ax2018.Nile plots=all;
	id date interval=year;
	step = (date > '31dec1898'd);
	trend level(rw) checkbreak;
	irregular wn;
	model Nile = step level wn;
	eval level_and_shift = step + level;
	output out=Out_Nile pdv;
run;

proc sgplot data=Out_Nile;
	title 'Nile and Level + Shift';
	band x=date lower=Smoothed_Lower_level_and_shift upper=Smoothed_Upper_level_and_shift;
	scatter x=date y=Nile;
	series x=date y=Smoothed_level_and_shift;
run;
