**********************************************;
* THREE TIME SERIES:                         *;
* Real_GDP = real US GDP                     *;
* CONS_EXP = real US Consumption and exports *;
* PRIVATE_INV = real US private investments  *;
* ALL SERIES ARE SEASONALLY ADJUSTED         *;
**********************************************;

data Ax2018.us_macro;
	set Ax2018.us_macro;
	date = INTNX( 'qtr', '1Jan1949'd, _N_ -1);
run;

proc sgplot data=Ax2018.US_MACRO;
	title 'Original time series';
	series x=date y=Real_GDP;
	series x=date y=CONS_EXP;
	series x=date y=PRIVATE_INV;
run;

data US_MACRO;
	set Ax2018.US_MACRO;
	loggdp = log(Real_GDP);
	logcon = log(CONS_EXP);
	loginv = log(PRIVATE_INV);
run;

proc sgplot data=US_MACRO;
	title 'Log-transformed time series';
	series x=date y=loggdp;
	series x=date y=logcon;
	series x=date y=loginv;
run;

title 'Order-1 cycle';
proc ucm data=US_MACRO;
	id date interval=qtr;
	model loginv;
	level variance=0 noest plot=smooth;
	slope;
	*season length=4 type=trig;
	cycle plot=smooth;
	irregular;
	estimate plot=panel;
run;

* LET US MAKE THE CYCLE SMOOTHER;

title 'Order-4 cycle';
proc ucm data=US_MACRO;
	id date interval=qtr;
	model loginv;
	level variance=0 noest plot=smooth;
	slope;
	*season length=4 type=trig;
	cycle order=4 plot=smooth; * the order option is not documented yet (experimental);
	irregular;
	estimate plot=panel;
run;

* WE CAN MODEL THE COMMON CYCLE USING SSM;

title 'Common cycle';
proc ssm data=US_MACRO;
	id date interval=qtr;
	dt=date;
	parms rho / lower=0.1 upper=0.99;
	parms per / lower=8 upper=32;
	parms cycoeff / lower=0;
	trend lev1(ps(2));
	trend lev2(ps(2));
	state cy(1) type=cycle(rho=rho period=per) cov(D);
	component cycle1 = cy[1];
	component cycle2 = (cycoeff) * cy[1];
	*state sea(2) type=season(length=4) cov(D);
	*component season1 = sea[1];
	*component season2 = sea[2];
	irregular noise1;
	irregular noise2;
	model logcon = lev1 cycle1 noise1;
	model loginv = lev2 cycle2 noise2;
	output out=out_US_MACRO PDV;
run;

proc sgplot data=out_US_MACRO;
	series x=date y=Smoothed_lev1;
	series x=date y=logcon / lineattrs=(color=red);
run;

proc sgplot data=out_US_MACRO;
	series x=date y=Smoothed_lev2;
	series x=date y=loginv / lineattrs=(color=red);
run;

proc sgplot data=out_US_MACRO;
	series x=date y=Smoothed_cycle1;
	series x=date y=Smoothed_cycle2;
run;
